@@ -30,7 +30,8 @@ util_replace_codes_by_NA <- function(study_data, meta_data,
       util_warning(
         c("Meta data does not provide a filled column",
           "called %s for replacing codes with NAs."),
-        dQuote(code_name))
+        dQuote(code_name),
+        applicability_problem = TRUE)
     }
   }
 
